/* SPDX-License-Identifier: GPL-2.0 WITH Linux-syscall-note */

#ifndef __NLDLM_H__
#define __NLDLM_H__

#define NLDLM_GENL_NAME "nldlm"

enum nldlm_commands {
	/* don't change the order or add anything between, this is ABI! */
	NLDLM_CMD_UNSPEC,

	NLDLM_CMD_GET_LS,
	__NLDLM_CMD_SET_LS,
	__NLDLM_CMD_NEW_LS,
	__NLDLM_CMD_DEL_LS,

	NLDLM_CMD_GET_NODE,
	__NLDLM_CMD_SET_NODE,
	NLDLM_CMD_NEW_NODE,
	NLDLM_CMD_DEL_NODE,

	NLDLM_CMD_GET_LS_MEMBER,
	__NLDLM_CMD_SET_LS_MEMBER,
	__NLDLM_CMD_NEW_LS_MEMBER,
	__NLDLM_CMD_DEL_LS_MEMBER,

	__NLDLM_CMD_GET_RSB,
	__NLDLM_CMD_SET_RSB,
	__NLDLM_CMD_NEW_RSB,
	__NLDLM_CMD_DEL_RSB,

	__NLDLM_CMD_GET_LKB,
	__NLDLM_CMD_SET_LKB,
	__NLDLM_CMD_NEW_LKB,
	__NLDLM_CMD_DEL_LKB,

	NLDLM_CMD_LS_EVENT,
	NLDLM_CMD_LS_EVENT_CTRL,
	NLDLM_CMD_LS_EVENT_DONE,
	NLDLM_CMD_LS_EVENT_ADD_MEMBER,
	NLDLM_CMD_LS_EVENT_DEL_MEMBER,

	NLDLM_CMD_GET_CONFIG,

	NLDLM_CMD_SET_OUR_NODE,
	NLDLM_CMD_SET_CLUSTER_NAME,
	NLDLM_CMD_SET_PROTOCOL,
	NLDLM_CMD_SET_PORT,
	NLDLM_CMD_SET_RECOVER_TIMEOUT,
	NLDLM_CMD_SET_INACTIVE_TIMEOUT,
	NLDLM_CMD_SET_LOG_LEVEL,
	NLDLM_CMD_SET_DEFAULT_MARK,
	NLDLM_CMD_SET_RECOVER_CALLBACKS,

	/* add new commands above here */

	/* used to define NLDLM_CMD_MAX below */
	__NLDLM_CMD_AFTER_LAST,
	NLDLM_CMD_MAX = __NLDLM_CMD_AFTER_LAST - 1
};

enum nldlm_attrs {
	/* don't change the order or add anything between, this is ABI! */
	NLDLM_ATTR_UNSPEC,

	NLDLM_ATTR_LS,
	NLDLM_ATTR_LS_MEMBER,
	NLDLM_ATTR_LS_EVENT,
	NLDLM_ATTR_NODE,
	NLDLM_ATTR_CFG,

	/* add attributes here, update the policy in nldlm.c */

	__NLDLM_ATTR_AFTER_LAST,
	NLDLM_ATTR_MAX = __NLDLM_ATTR_AFTER_LAST - 1
};

enum {
	NLDLM_EVENT_LS_NEW,
	NLDLM_EVENT_LS_RELEASE,
};

enum {
	NLDLM_EVENT_MEMBER_SUCCESS,
	NLDLM_EVENT_MEMBER_FAILURE,
};

enum {
	NLDLM_LS_CTRL_STOP,
	NLDLM_LS_CTRL_START,
};

enum {
	NLDLM_LS_EVENT_ATTR_UNSPEC,

	NLDLM_LS_EVENT_ATTR_LS,
	NLDLM_LS_EVENT_ATTR_TYPE,
	NLDLM_LS_EVENT_ATTR_CTRL,
	NLDLM_LS_EVENT_ATTR_RESULT,

	__NLDLM_LS_EVENT_ATTR_AFTER_LAST,
	NLDLM_LS_EVENT_ATTR_MAX = __NLDLM_LS_EVENT_ATTR_AFTER_LAST - 1
};

enum {
	NLDLM_LS_ATTR_UNSPEC,

	NLDLM_LS_ATTR_NAME,
	__NLDLM_LS_ATTR_ID,

	__NLDLM_LS_ATTR_AFTER_LAST,
	NLDLM_LS_ATTR_MAX = __NLDLM_LS_ATTR_AFTER_LAST - 1
};

enum {
	NLDLM_CFG_ATTR_UNSPEC,

	NLDLM_CFG_ATTR_OUR_NODE,
	NLDLM_CFG_ATTR_CLUSTER_NAME,
	NLDLM_CFG_ATTR_PROTOCOL,
	NLDLM_CFG_ATTR_PORT,
	NLDLM_CFG_ATTR_RECOVER_TIMEOUT,
	NLDLM_CFG_ATTR_INACTIVE_TIMEOUT,
	NLDLM_CFG_ATTR_LOG_LEVEL,
	NLDLM_CFG_ATTR_DEFAULT_MARK,
	NLDLM_CFG_ATTR_RECOVER_CALLBACKS,

	__NLDLM_CFG_ATTR_AFTER_LAST,
	NLDLM_CFG_ATTR_MAX = __NLDLM_CFG_ATTR_AFTER_LAST - 1
};

enum {
	NLDLM_ADDR_ATTR_UNSPEC,

	NLDLM_ADDR_ATTR_FAMILY,
	NLDLM_ADDR_ATTR_ADDR4,
	NLDLM_ADDR_ATTR_ADDR6,

	__NLDLM_ADDR_ATTR_AFTER_LAST,
	NLDLM_ADDR_ATTR_MAX = __NLDLM_ADDR_ATTR_AFTER_LAST - 1
};

enum {
	NLDLM_NODE_ATTR_UNSPEC,

	NLDLM_NODE_ATTR_ID,
	NLDLM_NODE_ATTR_MARK,
	NLDLM_NODE_ATTR_ADDRS,

	__NLDLM_NODE_ATTR_AFTER_LAST,
	NLDLM_NODE_ATTR_MAX = __NLDLM_NODE_ATTR_AFTER_LAST - 1
};

enum {
	NLDLM_LS_MEMBER_ATTR_UNSPEC,

	NLDLM_LS_MEMBER_ATTR_LS,
	NLDLM_LS_MEMBER_ATTR_NODE,
	NLDLM_LS_MEMBER_ATTR_WEIGHT,

	__NLDLM_LS_MEMBER_ATTR_AFTER_LAST,
	NLDLM_LS_MEMBER_ATTR_MAX = __NLDLM_LS_MEMBER_ATTR_AFTER_LAST - 1
};

enum {
	NLDLM_LOG_LEVEL_NONE,
	NLDLM_LOG_LEVEL_INFO,
	NLDLM_LOG_LEVEL_DEBUG,
};

enum {
	NLDLM_PROTOCOL_TCP,
	NLDLM_PROTOCOL_SCTP,
};

#endif /* __NLDLM_H__ */
